{
    --------------------------------------------
    Filename: six_counting_cogs.spin
    Version: 0.1, Initial Release
    Author: Jesse Burt
    Copyright (c) 2017
    See end of file for terms of use.
    --------------------------------------------
    This is an example of running six simple repeat loop
     methods, each in their own cog, and displaying
     the current iteration of each on a Parallax LCD.

    NOTE: The display.lcd.serial2 object is a  modified
     version of display.lcd.serial from the spin-standard-library
     (https://github.com/parallaxinc/spin-standard-library.git)
     but with the Dec, Hex and Bin methods added to it.
}

CON

  _clkmode = xtal1 + pll16x
  _xinfreq = 5_000_000

  LCD_IO_PIN  = 0
  LCD_BAUD    = 19_200          ' Change to suit your configuration
  LCD_LINES   = 4

OBJ

  lcd   : "display.lcd.serial2"
  time  : "time"

VAR

  long _cog2_var, _cog3_var, _cog4_var, _cog5_var, _cog6_var, _cog7_var
  long _cog2_stack[100], _cog3_stack[100], _cog4_stack[100], _cog5_stack[100]
  long _cog6_stack[100], _cog7_stack[100]

PUB Main                                      'Loaded into first COG, so you now have
                                              ' 7 left.

  lcd.Start (LCD_IO_PIN, LCD_BAUD, LCD_LINES) 'Uses a COG, so you now have 6 left
  lcd.EnableDisplay (TRUE)

  coginit(2, COG2_Method, @_cog2_stack)       'Usually there isn't a need to start a method
  coginit(3, COG3_Method, @_cog3_stack)       ' in a specific cog (use of coginit)
  coginit(4, COG4_Method, @_cog4_stack)       'It was only used here to illustrate as clearly
  coginit(5, COG5_Method, @_cog5_stack)       ' as possible what was being done in each cog.
  coginit(6, COG6_Method, @_cog6_stack)       'cognew(method, stackpointer) would usually
  coginit(7, COG7_Method, @_cog7_stack)       ' be used, instead, to simply use the next available cog.
 
  lcd.EnableBacklight (TRUE)                  ' Change to suit your configuration
                                              ' (FALSE if your LCD has no backlight, or you wish to disable it)

  lcd.Clear

  repeat
    lcd.Position (0, 0)

    lcd.Str (string("COG2="))
    lcd.Dec (_cog2_var)
    lcd.Str (string(" COG3="))
    lcd.Dec (_cog3_var)
    lcd.Str (string(" COG4="))
    lcd.Dec (_cog4_var)

    lcd.Position (0, 1)

    lcd.Str (string("COG5="))
    lcd.Dec (_cog5_var)
    lcd.Str (string(" COG6="))
    lcd.Dec (_cog6_var)
    lcd.Str (string(" COG7="))
    lcd.Dec (_cog7_var)

PUB COG2_Method

  repeat
    repeat _cog2_var from 0 to 9
      time.MSleep (512)

PUB COG3_Method

  repeat
    repeat _cog3_var from 0 to 9
      time.MSleep (256)

PUB COG4_Method

  repeat
    repeat _cog4_var from 0 to 9
      time.MSleep (128)

PUB COG5_Method

  repeat
    repeat _cog5_var from 9 to 0
      time.MSleep (500)

PUB COG6_Method

  repeat
    repeat _cog6_var from 9 to 0 
      time.MSleep (250)

PUB COG7_Method

  repeat
    repeat _cog7_var from 9 to 0
      time.MSleep (125)

DAT
{
    --------------------------------------------------------------------------------------------------------
    TERMS OF USE: MIT License

    Permission is hereby granted, free of charge, to any person obtaining a copy of this software and
    associated documentation files (the "Software"), to deal in the Software without restriction, including
    without limitation the rights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
    copies of the Software, and to permit persons to whom the Software is furnished to do so, subject to the
    following conditions:

    The above copyright notice and this permission notice shall be included in all copies or substantial
    portions of the Software.

    THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT
    LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
    IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
    WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
    SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
    --------------------------------------------------------------------------------------------------------
}
